# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-09-05 15:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ldpsource',
            name='container',
        ),
        migrations.AlterField(
            model_name='ldpsource',
            name='id',
            field=models.URLField(primary_key=True, serialize=False),
        ),
    ]
